@@ -2,9 +2,10 @@ import aiohttp
 import asyncio
 from arsein.Encoder import encoderjson
 from arsein.GtM import default_api
-from json import dumps, loads
-from random import choice
+from json import dumps, loads,JSONDecodeError
+from random import choice,randint
 from arsein.Clien import clien
+from arsein.Device import DeviceTelephone
 
 
 async def http(js,auth):
@@ -16,21 +17,13 @@ async def http(js,auth):
 			Post =  await response.text()
 			return Post
 
-async def rubino(js,auth,clien,method):
-	s = "https://rubino12.iranlms.ir"
-	enc = encoderjson(auth)
-	async with aiohttp.ClientSession() as session:
-		async with session.post(s, data = dumps({"api_version":"0","auth": auth,"client":clien,"data":js,"method":method})) as response:
-			Post =  await response.json()
-			return Post
-
-async def httpregister(js,auth):
+async def httpregister(auth):
 	Full = default_api()
 	s = Full.defaultapi()
 	enc = encoderjson(auth)
 	async with aiohttp.ClientSession() as session:
-		async with session.post(s, data = dumps({"api_version":"5","auth": auth,"method":"registerDevice","client": clien.android,"data_enc":enc.encrypt(dumps(js))}) , headers = {'Content-Type': 'application/json'}) as response:
-			Post =  await response.text()
+		async with session.post(s, data = dumps({"api_version":"4","auth":auth,"client": clien.android,"data_enc":enc.encrypt(dumps(DeviceTelephone.defaultDevice)),"method":"registerDevice"})) as response:
+			Post =  await response.json()
 			return Post
 
 
@@ -73,8 +66,7 @@ class method_Rubika:
 				elif self.Type == "file":
 					return loop.run_until_complete(httpfiles(self.serverfile,self.datafile,self.headerfile))
 					break
-				elif self.Type == "rubino":
-					return loads(self.enc.decrypt(loads(loop.run_until_complete(rubino(indata,self.Auth,wn,methode))).get("data_enc")))
-					break
+			except JSONDecodeError:
+				continue
 			except:
 				continue
